@@ -66,6 +66,7 @@ func TestCRUD(t *testing.T) {
 }
 
 const (
+	deployNg        = "ng-deploy"
 	deleteNg        = "ng-delete"
 	taintsNg1       = "ng-taints-1"
 	taintsNg2       = "ng-taints-2"
@@ -131,6 +132,17 @@ var _ = SynchronizedBeforeSuite(func() []byte {
 		},
 	}
 	cfg.ManagedNodeGroups = []*api.ManagedNodeGroup{
+		{
+			NodeGroupBase: &api.NodeGroupBase{
+				Name: deployNg,
+				ScalingConfig: &api.ScalingConfig{
+					DesiredCapacity: aws.Int(5),
+				},
+				Labels: map[string]string{
+					"used-for": "test-pods",
+				},
+			},
+		},
 		{
 			NodeGroupBase: &api.NodeGroupBase{
 				Name: drainMng,
@@ -214,7 +226,7 @@ var _ = Describe("(Integration) Create, Get, Scale & Delete", func() {
 			Expect(session.ExitCode()).To(BeZero())
 			var stacks []*cfntypes.Stack
 			Expect(yaml.Unmarshal(session.Out.Contents(), &stacks)).To(Succeed())
-			Expect(stacks).To(HaveLen(6))
+			Expect(stacks).To(HaveLen(7))
 
 			var (
 				names, descriptions []string
@@ -227,6 +239,7 @@ var _ = Describe("(Integration) Create, Get, Scale & Delete", func() {
 
 			Expect(names).To(ContainElements(
 				ContainSubstring(params.ClusterName+"-cluster"),
+				ContainSubstring(ngPrefix+deployNg),
 				ContainSubstring(ngPrefix+deleteNg),
 				ContainSubstring(ngPrefix+scaleSingleNg),
 				ContainSubstring(ngPrefix+scaleMultipleNg),
@@ -261,7 +274,7 @@ var _ = Describe("(Integration) Create, Get, Scale & Delete", func() {
 		})
 
 		It("should deploy podinfo service to the cluster and access it via proxy", func() {
-			d := test.CreateDeploymentFromFile(test.Namespace, "../../data/podinfo.yaml")
+			d := test.CreateDeploymentFromFile(test.Namespace, "../../data/crud-podinfo.yaml")
 			test.WaitForDeploymentReady(d, commonTimeout)
 
 			pods := test.ListPodsFromDeployment(d)
@@ -520,7 +533,7 @@ var _ = Describe("(Integration) Create, Get, Scale & Delete", func() {
 				"1.1.1.1/32,2.2.2.0/24",
 				"--approve",
 			)).To(RunSuccessfully())
-			Expect(k8sAPICall()).Should(HaveOccurred())
+			Eventually(k8sAPICall, "5m", "20s").Should(HaveOccurred())
 		})
 
 		It("should re-enable public access", func() {
@@ -898,7 +911,7 @@ var _ = Describe("(Integration) Create, Get, Scale & Delete", func() {
 				"--timeout=45m",
 				"--cluster", params.ClusterName,
 				"--nodes", "1",
-				"--instance-types", "p2.xlarge,p3.2xlarge,p3.8xlarge,g3s.xlarge,g4ad.xlarge,g4ad.2xlarge",
+				"--instance-types", "p3.2xlarge,p3.8xlarge,g3s.xlarge,g4ad.xlarge,g4ad.2xlarge",
 				"--node-private-networking",
 				"--node-zones", "us-west-2b,us-west-2c",
 				GPUMng,
@@ -970,7 +983,6 @@ var _ = Describe("(Integration) Create, Get, Scale & Delete", func() {
 					"--timeout", time.Hour.String(),
 					"--cluster", params.ClusterName,
 					"--nodes", "1",
-					"--node-type", "p2.xlarge",
 					"--subnet-ids", extraSubnetID,
 					newSubnetCLIMng,
 				)).To(RunSuccessfully())
@@ -1197,6 +1209,7 @@ var _ = Describe("(Integration) Create, Get, Scale & Delete", func() {
 				"-o", "json",
 				"--cluster", params.ClusterName,
 			)).To(RunSuccessfullyWithOutputString(BeNodeGroupsWithNamesWhich(
+				ContainElement(deployNg),
 				ContainElement(taintsNg1),
 				ContainElement(taintsNg2),
 				ContainElement(scaleSingleNg),
