@@ -125,6 +125,11 @@ var expectedTemplate = `{
                 "ec2:DescribeSpotPriceHistory",
                 "iam:PassRole",
                 "iam:CreateServiceLinkedRole",
+                "iam:GetInstanceProfile",
+                "iam:CreateInstanceProfile",
+                "iam:DeleteInstanceProfile",
+                "iam:TagInstanceProfile",
+                "iam:AddRoleToInstanceProfile",
                 "ssm:GetParameter",
                 "pricing:GetProducts"
               ],
@@ -262,6 +267,11 @@ var expectedTemplateWithPermissionBoundary = `{
                 "ec2:DescribeSpotPriceHistory",
                 "iam:PassRole",
                 "iam:CreateServiceLinkedRole",
+                "iam:GetInstanceProfile",
+                "iam:CreateInstanceProfile",
+                "iam:DeleteInstanceProfile",
+                "iam:TagInstanceProfile",
+                "iam:AddRoleToInstanceProfile",
                 "ssm:GetParameter",
                 "pricing:GetProducts"
               ],
@@ -424,6 +434,11 @@ var expectedTemplateWithSpotInterruptionQueue = `{
                 "ec2:DescribeSpotPriceHistory",
                 "iam:PassRole",
                 "iam:CreateServiceLinkedRole",
+                "iam:GetInstanceProfile",
+                "iam:CreateInstanceProfile",
+                "iam:DeleteInstanceProfile",
+                "iam:TagInstanceProfile",
+                "iam:AddRoleToInstanceProfile",
                 "ssm:GetParameter",
                 "pricing:GetProducts"
               ],
